@@ -1,6 +1,9 @@
+import logging
 from prompt_toolkit.keys import Keys
 from prompt_toolkit.enums import InputMode
 
+_logger = logging.getLogger(__name__)
+
 def pgcli_bindings(registry, cli_ref):
     """
     Custom key bindings for pgcli.
@@ -13,6 +16,7 @@ def pgcli_bindings(registry, cli_ref):
         """
         Enable/Disable SmartCompletion Mode.
         """
+        _logger.debug('Detected F2 key.')
         line.completer.smart_completion = not line.completer.smart_completion
 
     @handle(Keys.F3)
@@ -20,12 +24,13 @@ def pgcli_bindings(registry, cli_ref):
         """
         Enable/Disable Multiline Mode.
         """
-        #import pdb; pdb.set_trace()
+        _logger.debug('Detected F3 key.')
         line.always_multiline = not line.always_multiline
 
     @handle(Keys.ControlSpace, in_mode=InputMode.INSERT)
     def _(event):
         """
-        Force autocompletion at cursor
+        Force autocompletion at cursor.
         """
+        _logger.debug('Detected <C-Space> key.')
         line.complete_next()
