@@ -1,7 +1,16 @@
 from __future__ import print_function
+import sys
 import sqlparse
 from sqlparse.sql import Comparison
-from parseutils import last_word, extract_tables, find_prev_keyword
+from .parseutils import last_word, extract_tables, find_prev_keyword
+
+PY2 = sys.version_info[0] == 2
+PY3 = sys.version_info[0] == 3
+
+if PY3:
+    string_types = str
+else:
+    string_types = basestring
 
 
 def suggest_type(full_text, text_before_cursor):
@@ -37,7 +46,7 @@ def suggest_type(full_text, text_before_cursor):
     return suggest_based_on_last_token(last_token, text_before_cursor, full_text)
 
 def suggest_based_on_last_token(token, text_before_cursor, full_text):
-    if isinstance(token, basestring):
+    if isinstance(token, string_types):
         token_v = token
     else:
         # If 'token' is a Comparison type such as
