@@ -1,9 +1,12 @@
 from __future__ import print_function
+import logging
 from collections import defaultdict
 from prompt_toolkit.completion import Completer, Completion
 from .packages.sqlcompletion import suggest_type
 from .packages.parseutils import last_word
 
+_logger = logging.getLogger(__name__)
+
 class PGCompleter(Completer):
     keywords = ['ACCESS', 'ADD', 'ALL', 'ALTER TABLE', 'AND', 'ANY', 'AS',
             'ASC', 'AUDIT', 'BETWEEN', 'BY', 'CASE', 'CHAR', 'CHECK',
@@ -63,6 +66,7 @@ class PGCompleter(Completer):
         self.all_completions.update(columns)
 
     def reset_completions(self):
+        self.databases = []
         self.tables = []
         self.columns = defaultdict(lambda: ['*'])
         self.all_completions = set(self.keywords)
@@ -74,33 +78,42 @@ class PGCompleter(Completer):
             if item.startswith(text) or item.startswith(text.upper()):
                 yield Completion(item, -len(text))
 
-    def get_completions(self, document, complete_event):
-
+    def get_completions(self, document, complete_event, smart_completion=None):
         word_before_cursor = document.get_word_before_cursor(WORD=True)
+        if smart_completion is None:
+            smart_completion = self.smart_completion
 
         # If smart_completion is off then match any word that starts with
         # 'word_before_cursor'.
-        if not self.smart_completion:
+        if not smart_completion:
             return self.find_matches(word_before_cursor, self.all_completions)
 
         category, scope = suggest_type(document.text,
                 document.text_before_cursor)
 
         if category == 'columns':
-            scoped_cols = []
-            for table in scope:
-                scoped_cols.extend(self.columns[table])
+            _logger.debug("Completion: 'columns' Scope: %r", scope)
+            scoped_cols = self.populate_scoped_cols(scope)
             return self.find_matches(word_before_cursor, scoped_cols)
         elif category == 'columns-and-functions':
-            scoped_cols = []
-            for table in scope:
-                scoped_cols.extend(self.columns[table])
+            _logger.debug("Completion: 'columns-and-functions' Scope: %r",
+                    scope)
+            scoped_cols = self.populate_scoped_cols(scope)
             return self.find_matches(word_before_cursor, scoped_cols +
                     self.functions)
         elif category == 'tables':
+            _logger.debug("Completion: 'tables' Scope: %r", scope)
             return self.find_matches(word_before_cursor, self.tables)
         elif category == 'databases':
+            _logger.debug("Completion: 'databases' Scope: %r", scope)
             return self.find_matches(word_before_cursor, self.databases)
         elif category == 'keywords':
+            _logger.debug("Completion: 'keywords' Scope: %r", scope)
             return self.find_matches(word_before_cursor, self.keywords +
                     self.special_commands)
+
+    def populate_scoped_cols(self, tables):
+        scoped_cols = []
+        for table in tables:
+            scoped_cols.extend(self.columns[table])
+        return scoped_cols
